==> recruit-drop-list-1.0.9.tgz: package/src/createPage.js <==
import React, {Component} from 'react';
import Textbox from '@beisen-platform/ethos/lib/Textbox';

const emailTest = /^(\w-*\.*)+@(\w-?)+(\.\w{2,})+$/;
const phoneTest = /^1\d{10}$/;

export default class CreatePage extends Component {
	constructor(props) {
	    super(props);
	    this.state = {
	    	nameRequired: false
	    	,emailRequired: false
	    	,wrongEmail: false
	    	,wrongPhone: false
	    	,nameValue: ''
	    	,emailValue: ''
	    	,phoneValue: ''
	    	,isEmailError: false
	    }

	    this.validateAll = this.validateAll.bind(this);
	}

	componentWillReceiveProps(nextProps) {
		if (nextProps.isEmailError !== this.props.isEmailError) {
			this.setState({isEmailError: nextProps.isEmailError});
		}
	}

	isRequired(value) {
		return value == '';
	}

	validateAll() {
		this.validateName(this.state.nameValue);
		this.validateEmail(this.state.emailValue);
		this.validateEmailDuplicate(this.state.emailValue);
		this.validatePhone(this.state.phoneValue);
	}

	validateName(value) {
		this.setState({
			nameValue: value
			,nameRequired: this.isRequired(value)
		});
	}

	validateEmail(value) {
		this.setState({
			emailValue: value
			,emailRequired: this.isRequired(value)
			,wrongEmail: !emailTest.test(value)
		});
	}

	validateEmailDuplicate(value) {
		this.props.validateEmail && this.props.validateEmail(value);
	}

	validatePhone(value) {
		if (value == '') return false;
		this.setState({
			phoneValue: value
			,wrongPhone: !phoneTest.test(value)
		});
	}

	render() {
		const self = this;
		const { nameValue, emailValue, phoneValue, nameRequired, emailRequired, wrongEmail, wrongPhone, isEmailError } = this.state;
		const props1 = {
			showTag: '姓名',
			defaultValue: nameValue,
			required: true,
			errorStatus: nameRequired,
			errorMsg: '请填写姓名',
			lablePos: true,   //label位置，true时在左边，false在上边
			onChange: function(event, status, value){},
			onBlur: function(event, status, value){
				self.validateName(value)
			}
		}
		const props2 = {
			showTag: '邮箱',
			defaultValue: emailValue,
			required: true,
			errorStatus: emailRequired || wrongEmail || isEmailError,
			errorMsg: emailRequired ? '请填写邮箱' : ( wrongEmail ? '邮箱格式错误' : this.props.emailErrorTip),
			lablePos: true,   //label位置，true时在左边，false在上边
			onChange: function(event, status, value){},
			onBlur: function(event, status, value){
				self.validateEmail(value);
				self.validateEmailDuplicate(value);
			}
		}
		const props3 = {
			showTag: '手机',
			defaultValue: phoneValue,
			required: false,
			errorStatus: wrongPhone,
			errorMsg: '手机格式错误',
			lablePos: true,   //label位置，true时在左边，false在上边
			onChange: function(event, status, value){},
			onBlur: function(event, status, value){
				self.validatePhone(value)
			}
		}

		return (
			<div className='create-page'>
				<Textbox {...props1} />
				<Textbox {...props2} />
				<Textbox {...props3} />
			</div>
		)
	}
}

==> recruit-drop-list-1.0.18.tgz: package/src/createPage.js <==
import React, {Component} from 'react';
import Textbox from '@beisen-platform/ethos/lib/Textbox';

const emailTest = /^(\w-*\.*)+@(\w-?)+(\.\w{2,})+$/;
const phoneTest = /^1\d{10}$/;

export default class CreatePage extends Component {
	constructor(props) {
	    super(props);
	    this.state = {
	    	nameRequired: false
	    	,emailRequired: false
	    	,wrongEmail: false
	    	,wrongPhone: false
	    	,nameValue: ''
	    	,emailValue: ''
	    	,phoneValue: ''
	    	,isEmailError: false
	    }

	    this.validateAll = this.validateAll.bind(this);
	}

	componentWillReceiveProps(nextProps) {
		if (nextProps.isEmailError !== this.state.isEmailError) {
			this.setState({isEmailError: nextProps.isEmailError});
		}
	}

	isRequired(value) {
		return value == '';
	}

	validateAll() {
		this.validateName(this.state.nameValue);
		this.validateEmail(this.state.emailValue);
		this.validateEmailDuplicate(this.state.emailValue);
		this.validatePhone(this.state.phoneValue);
	}

	validateName(value) {
		this.setState({
			nameValue: value
			,nameRequired: this.isRequired(value)
		});
	}

	validateEmail(value) {
		this.setState({
			emailValue: value
			,emailRequired: this.isRequired(value)
			,wrongEmail: !emailTest.test(value)
		});
	}

	validateEmailDuplicate(value) {
		this.props.validateEmail && this.props.validateEmail(value);
	}

	validatePhone(value) {
		if (value == '') return false;
		this.setState({
			phoneValue: value
			,wrongPhone: !phoneTest.test(value)
		});
	}

	render() {
		const self = this;
		const { nameValue, emailValue, phoneValue, nameRequired, emailRequired, wrongEmail, wrongPhone, isEmailError } = this.state;
		const props1 = {
			showTag: '姓名',
			defaultValue: nameValue,
			required: true,
			errorStatus: nameRequired,
			errorMsg: '请填写姓名',
			lablePos: true,   //label位置，true时在左边，false在上边
			onChange: function(event, status, value){},
			onBlur: function(event, status, value){
				self.validateName(value)
			}
		}
		const props2 = {
			showTag: '邮箱',
			defaultValue: emailValue,
			required: true,
			errorStatus: emailRequired || wrongEmail || isEmailError,
			errorMsg: emailRequired ? '请填写邮箱' : ( wrongEmail ? '邮箱格式错误' : this.props.emailErrorTip),
			lablePos: true,   //label位置，true时在左边，false在上边
			onChange: function(event, status, value){},
			onBlur: function(event, status, value){
				self.validateEmail(value);
				self.validateEmailDuplicate(value);
			}
		}
		const props3 = {
			showTag: '手机',
			defaultValue: phoneValue,
			required: false,
			errorStatus: wrongPhone,
			errorMsg: '手机格式错误',
			lablePos: true,   //label位置，true时在左边，false在上边
			onChange: function(event, status, value){},
			onBlur: function(event, status, value){
				self.validatePhone(value)
			}
		}

		return (
			<div className='create-page'>
				<Textbox {...props1} />
				<Textbox {...props2} />
				<Textbox {...props3} />
			</div>
		)
	}
}
